<%inherit file="basewithmenu.html" /> <%block name="head"> ${parent.head()}
<%block name="menu2">
×

### Upload documents

Upload to: Select an existing dataset to add documents to or type a new name to create it

Data file:

Format:

- Id,Text: a csv file, with two columns, the first is a unique ID, the second the text content.
- Id,IsoDateTime,Text: text is in the third column, the second one contains the creation date formated as specified by the datetime.fromisoformat function. E.g., "2011-11-04 00:05:23".

Uploading

×

### Rename a dataset

Classifier to rename:

New name:

Processing

×

### Change description

Dataset:

Description:

Processing

×

### Delete a dataset

Classifier to delete:

Processing